/*****************************************************************************\
*                                                                             *
* LiveIPAddress: Retrieves your Live IP Address and displays it on Firefox's  *
*                status bar.                                                  *
*                                                                             *
* Version 1.5                                              Date: 27 Jan 2006 *
*                                                                             *
* In the currect version the following features are functioned:               *
*    1. By single-clicking on the IP address field in Firefox's status bar,   *
*       the extension checks for changes in the IP value.                     *
*    2. Under the Tools menu-item, an entry called Live IP Address has been   *
*       added which reveals 3 sub-menu options: i) Copy Live IP Address,      *
*       ii) Force Update Now and iii) Set Update Interval.                    *
*    3. When the user right clicks inside the web browser, the right-click    *
*       list displays a new entry called "Copy Live IP Address", if the user  *
*       select this option a prompt box pops up displaying the IP, where the  *
*       user may copy that into the clipboard.                                *
*    5. Two more IP-Finders have been added (out of 3) to make the extension  *
*       more reliable and robust.                                             *
*    4. Added locales: French, German and Greek                               *
*                                                                             *
* Copyright 2006 Anastasios Monachos                                          *
* Email: anastasiosm@hotmail.com                                              *
*                                                                             *
* Inspired by the Public IP - Firefox Extention created by Daniel Wood        *
* (http://www.maleman876.com/) - as I would prefare showing my live IP        *
* address permanently in the status bar.                                      *
*                                                                             *
* This program is free software; you can redistribute it and/or modify it     *
* under the terms of the GNU General Public License as published by the Free  *
* Software Foundation; either version 2 of the License, or (at your option)   *
* any later version.                                                          *
*                                                                             *
* This program is distributed in the hope that it will be useful, but WITHOUT *
* ANY WARRANTY; without even the implied warranty of MERCHANTIBLITY or        *
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for   *
* more details.                                                               *
*                                                                             *
* You should have received a copy of the GNU General Public License along     *
* with this program; if not, write to the Free Software Foundation, Inc.,     *
* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.                    *
*                                                                             *
\*****************************************************************************/

var realIPAddress;//Exported value for realIPAddress
var refreshEveryMilliSeconds = 1000000;//Set here the default value to check for IP changes (in milliseconds)
var NumberOfIPFinders = 3;

/***************************************************************************
	Get user's value, check for valid input and if OK call 
	convertMinutesToMilliSeconds.
***************************************************************************/
function setRefreshRateDialog()
{
	var input = prompt('Please enter a value in minutes to set how often you want to check for IP changes.\nValid values in range 17 - 1422.')
	if (input>=17 && input<=1422)
	{
		convertMinutesToMilliSeconds(input)
	}
	else if (input<17 || input>1422 || input=="" || input==null)
	{
		alert('Invalid input.  Please try again.');
		refreshEveryMilliSeconds = 1000000;
		updateliveipaddress();
	}
}

/***************************************************************************
  As the name of the function tells, this converts user's input refresh time
  from minutes to milliseconds, and the passes the control to the 
  updateliveipaddress function.
***************************************************************************/
function convertMinutesToMilliSeconds(valueFromsetRefreshRateDialog)
{
	refreshEveryMilliSeconds = valueFromsetRefreshRateDialog * 60 * 1000;
	updateliveipaddress();
}

/***************************************************************************
	This function is called when:
	i) the user right clicks on a page in FF and chooses "Copy Live IP 
	Address" or 
	ii) the user chooses the corresponding selection from the Tools |
	Live IP Address | Copy Live IP Address option.
***************************************************************************/
function copyIPAddressInfoBox()
{
	prompt('Your Live IP Address is:', realIPAddress)
}

/***************************************************************************
	This is the first thing that is being called from the XUL file.
***************************************************************************/
function updateliveipaddress()
{
	randomNumberGenerator()
	self.setTimeout('updateliveipaddress()', refreshEveryMilliSeconds);//Remember to check for IP changes
}

window.addEventListener("load", updateliveipaddress, false);

/***************************************************************************
	This function will create a random number in the range 0 to 
	NumberOfIPFinders. As you will notice each IPFinder has intentionally
	its own modular function.
***************************************************************************/
function randomNumberGenerator()
{
	var randomNumber;

	randomNumber = Math.floor(NumberOfIPFinders*Math.random())
	
	if (randomNumber == 0)
	{
		makeRequestIpFooComXML('http://www.ipfoo.com/xml/', '');
	}
	else if (randomNumber == 1)
	{
		makeRequestShowMyIPComXML('http://www.showmyip.com/xml/', '');

	}
	else if (randomNumber == 2)
	{
		makeRequestFilezillaSourceforge();
	}
}

/***************************************************************************
	Is being called when the random generated number equals to 0

	Start of http://www.ipfoo.com/xml/

	Thanks to Brad B See comments "Excellent Script" at Live IP Address site:
	https://addons.mozilla.org/extensions/moreinfo.php?application=firefox&id=1731&&page=comments
	for providing us the URL : www.ipfoo.com/xml/
***************************************************************************/
function makeRequestIpFooComXML(url, parameters)
{
	http_request = false;
	http_request = new XMLHttpRequest();
	
	if (http_request.overrideMimeType)
	{
		http_request.overrideMimeType('text/xml');
	}
	if (!http_request)
	{
		var linkstatusmessage = alert(document.getElementById('liveipaddress-strings').getString("ImpossibleCreation"));
		return false;
	}

	http_request.onreadystatechange = wwwipfoocom;
	http_request.open('GET', url + parameters, true);
	http_request.send(null);
}
function wwwipfoocom()
{
	if (http_request.readyState == 4)
	{
		if (http_request.status == 200)
		{
			var xmlobject = http_request.responseXML;
			var root = xmlobject.getElementsByTagName('ip_address')[0];
			var element = root.getElementsByTagName("ip");
			var liveipvalue = element[0].firstChild.nodeValue;

			document.getElementById('LiveIPAddressPanel').label = liveipvalue;
			
			//(Double check) Usually "undefined" is the value we get if we have reached the daily limit (=300 times).
			if (liveipvalue != "undefined")
			{
				realIPAddress = liveipvalue; //This assignment is used only by the copyIPAddressInfoBox().
			}
		}
		else
		{
			alert(document.getElementById('liveipaddress-strings').getString("RequestProblem"));
		}
	}

	return realIPAddress
}//End of http://www.ipfoo.com/xml/

/***************************************************************************
	Is being called when the random generated number equals to 1

	Start of http://www.showmyip.com

	The following two functions are being used for the www.showmyip.com
***************************************************************************/
function makeRequestShowMyIPComXML(url, parameters)
{
	http_request = false;
	http_request = new XMLHttpRequest();
	
	if (http_request.overrideMimeType)
	{
		http_request.overrideMimeType('text/xml');
	}
	if (!http_request)
	{
		var linkstatusmessage = alert(document.getElementById('liveipaddress-strings').getString("ImpossibleCreation"));
		return false;
	}

	http_request.onreadystatechange = wwwshowmyipcom;
	http_request.open('GET', url + parameters, true);
	http_request.send(null);
}

function wwwshowmyipcom()
{
	if (http_request.readyState == 4)
	{
		if (http_request.status == 200)
		{
			var xmlobject = http_request.responseXML;
			var root = xmlobject.getElementsByTagName('ip_address')[0];
			var element = root.getElementsByTagName("ip");
			var liveipvalue = element[0].firstChild.nodeValue;
			
			document.getElementById('LiveIPAddressPanel').label = liveipvalue;

			//(Double check) Usually "undefined" is the value we get if we have reached the daily limit (=300 times).
			if (liveipvalue != "undefined")
			{
				realIPAddress = liveipvalue; //This assignment is used only by the copyIPAddressInfoBox().
			}
		}
		else
		{
			alert(document.getElementById('liveipaddress-strings').getString("RequestProblem"));
		}
	}
}//End of http://www.showmyip.com

/***************************************************************************
	Is being called when the random generated number equals to 2

	Start of http://filezilla.sourceforge.net/misc/ip.php

	Thanks to Ares see comments "Works as advertised" at Live IP Address 
	site: https://addons.mozilla.org/extensions/moreinfo.php?application=firefox&id=1731&&page=comments
	for providing us the URL : filezilla.sourceforge.net/misc/ip.php
***************************************************************************/
function makeRequestFilezillaSourceforge()
{
	var http_request=false;

	if (!http_request && typeof XMLHttpRequest != 'undefined')
	{
		http_request = new XMLHttpRequest();

		if (http_request.overrideMimeType)
		{
			http_request.overrideMimeType('text/plain');
		}
	}
	
	http_request.onreadystatechange = function()//Check if the page has been loaded
	{
		if (http_request.readyState == 4 && http_request.status == 200)//Loading page completed, and page is OK
		{
			realIPAddress = http_request.responseText;//This assignment is used only by the copyIPAddressInfoBox().

			if (realIPAddress != "undefined")
			{
				//now do the hack, for some reason filezilla's site reaturns two extra characters along with IP, so we have to exclude these
				var realIPAddressLength = realIPAddress.length; //This is the length which is being returned from filezilla
				var realIPAddressDump = ""
				var fixedRealIPAddressLength = "";//Needs to have a zero-length value
				fixedRealIPAddressLength = (realIPAddressLength - 2);
				
				//An IP can be consisted by up to 15 characters/elements (e.g. 111.111.111.111)
				var IP = new Array(14)

				for (i=0;i<fixedRealIPAddressLength;i++)//Now get only the useful elements (those 15 if of type 111.111.111.111)
				{
					IP[i]=realIPAddress.charAt(i);
					realIPAddressDump = realIPAddressDump + IP[i];//Construct (realIPAddress from) realIPAddressDump
				}
				realIPAddress = realIPAddressDump;//Pointless but helps keeping things consistent (ie similar with other makeRequestXYZ methods).

				document.getElementById('LiveIPAddressPanel').label = realIPAddress;//Display the IP on FF status bar, as always.			
			}
		}
	}

	http_request.open("GET", "http://filezilla.sourceforge.net/misc/ip.php", true);//Sends HTTP GET command, ASync=True
	http_request.send(null);
}//End of http://filezilla.sourceforge.net/misc/ip.php

